@@ -1,7 +1,7 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: October 2, 2015
+# Last Change: October 4, 2015
 # URL: https://executor.readthedocs.org
 
 """
@@ -20,13 +20,13 @@ logging :-).
 import logging
 import os
 
+# External dependencies.
+from humanfriendly import concatenate, pluralize, Timer
+from property_manager import mutable_property, required_property
+
 # Modules included in our package.
 from executor import DEFAULT_WORKING_DIRECTORY, ExternalCommand, ExternalCommandFailed, quote
 from executor.concurrent import CommandPool
-from executor.property_manager import mutable_property, required_property
-
-# External dependencies.
-from humanfriendly import concatenate, pluralize, Timer
 
 # Initialize a logger.
 logger = logging.getLogger(__name__)
